@@ -11,4 +11,6 @@ class AlreadyInstalledException(Exception):
     """General exception during installing"""
 class NotSupportedVersionException(Exception):
     """General exception during installing"""
-    
\ No newline at end of file
+    
+class CurlFetchException(Exception):
+    """Exception curl during fetching"""
